ascender property
Distance from the baseline to the top of the em square, in font units.
Positive value (above baseline).
Implementation
final int ascender;
Distance from the baseline to the top of the em square, in font units.
Positive value (above baseline).
final int ascender;