capHeight property
Height of capital letters above the baseline, in font units.
Sourced from the OS/2 table (version ≥ 2). Zero if unavailable.
Implementation
final int capHeight;
Height of capital letters above the baseline, in font units.
Sourced from the OS/2 table (version ≥ 2). Zero if unavailable.
final int capHeight;