FramePhase enum

Various important time points in the lifetime of a frame.

FrameTiming records a timestamp of each phase for performance analysis.

Inheritance
Available extensions

Values

vsyncStart → const FramePhase

The timestamp of the vsync signal given by the operating system.

See also FrameTiming.vsyncOverhead.

buildStart → const FramePhase

When the UI thread starts building a frame.

See also FrameTiming.buildDuration.

buildFinish → const FramePhase

When the UI thread finishes building a frame.

See also FrameTiming.buildDuration.

rasterStart → const FramePhase

When the raster thread starts rasterizing a frame.

See also FrameTiming.rasterDuration.

rasterFinish → const FramePhase

When the raster thread finishes rasterizing a frame.

See also FrameTiming.rasterDuration.

rasterFinishWallTime → const FramePhase

When the raster thread finished rasterizing a frame in wall-time.

This is useful for correlating time raster finish time with the system clock to integrate with other profiling tools.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<FramePhase>
A constant List of the values in this enum, in order of their declaration.