GlyphContour class

A closed contour (outline loop) within a glyph.

The last point implicitly connects back to the first, closing the contour. Contours are wound clockwise for filled areas and counter-clockwise for holes (counter inside counter = filled, etc.).

Constructors

GlyphContour(List<GlyphPoint> points)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
points List<GlyphPoint>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
transformed(double a, double b, double c, double d) GlyphContour
translated(double dx, double dy) GlyphContour

Operators

operator ==(Object other) bool
The equality operator.
inherited