fromUint8List static method
Creates a copy of the data from a Uint8List suitable for internal use in the engine.
Implementation
static Future<ImmutableBuffer> fromUint8List(Uint8List list) async {
return _PureDartImmutableBuffer(list);
}
Creates a copy of the data from a Uint8List suitable for internal use in the engine.
static Future<ImmutableBuffer> fromUint8List(Uint8List list) async {
return _PureDartImmutableBuffer(list);
}