GlyphOutline class
The complete outline of a single glyph, in font design units.
Instances are produced by TtfFont.getGlyphOutline.
advanceWidth is the horizontal advance width (how far to move the pen after this glyph). lsb is the left side bearing (distance from the pen origin to the start of the ink bounding box).
Both advanceWidth and lsb are in font design units. Multiply by
fontSize / font.metrics.unitsPerEm to convert to pixels.
Constructors
-
GlyphOutline({required List<
GlyphContour> contours, required double advanceWidth, required double lsb}) -
const
Properties
- advanceWidth → double
-
Advance width in font design units.
final
-
contours
→ List<
GlyphContour> -
The contours that form the glyph's outline.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
no setter
- lsb → double
-
Left side bearing in font design units.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited