LayoutLine class
A single laid-out line of text within a paragraph.
Produced by layoutText. All positions are relative to the top-left of the paragraph (i.e. the Offset passed to Canvas.drawParagraph is applied separately by the renderer).
Constructors
Properties
- ascent → double
-
Pixels above the baseline (positive value).
final
- baseline → double
-
Y position of the baseline measured from the paragraph's top edge.
final
- descent → double
-
Pixels below the baseline (positive value).
final
-
glyphs
→ List<
ShapedGlyph> -
The shaped glyphs that make up this line, in visual order.
final
- hardBreak → bool
-
True when this line ends with an explicit
\nor is the last line.final - hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
no setter
- left → double
-
Horizontal offset from the paragraph's left edge, applied by TextAlign.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double
-
Total advance width of the line's glyphs.
final
-
xOffsets
→ List<
double> -
X offset of each glyph from the line's left ink edge (before left).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited